Learn R Programming

SeqKat (version 0.0.9)

get.exprobntcx: get.exprobntcx

Description

Gets the expected probability for each trinucleotide and total number of tcx

Usage

get.exprobntcx(somatic, ref.dir, trinucleotide.count.file)

Arguments

somatic

Data frame of somatic variants

ref.dir

Path to a directory containing the reference genome.

trinucleotide.count.file

A tab seprarated file containing a count of all trinucleotides present in the reference genome. This can be generated with the get.trinucleotide.counts() function in this package.

Author

Fan Fan

Fouad Yousif

Examples

Run this code
load(
	paste0(
		path.package("SeqKat"),
		"/extdata/test/somatic.rda"
		)
	);

trinucleotide.count.file <- paste0(
	path.package("SeqKat"),
	"/extdata/tn_count.txt"
	);

example.ref.dir <- paste0(
	path.package("SeqKat"),
	"/extdata/test/ref/"
	);

get.exprobntcx(somatic, example.ref.dir, trinucleotide.count.file)

Run the code above in your browser using DataLab